from pathlib import Path
from typing import List

from phenopackets import PhenotypicFeature
from pheval.utils.file_utils import all_files
from pheval.utils.phenopacket_utils import PhenopacketUtil, phenopacket_reader


def write_hpo_ids_to_output_file(
    output_file: Path, phenotypic_profile: List[PhenotypicFeature]
) -> None:
    """
    Write a list of HPO ids to a new text file for input into Phen2Gene.
    Args:
        output_file (Path): Path to the file to write text file containing HPO ids.
        phenotypic_profile (List[PhenotypicFeature]): List of phenotypic features.
    """
    with open(output_file, "w") as output:
        output.write("\n".join([hpo.type.id for hpo in phenotypic_profile]))
    output.close()


def prepare_input(output_dir: Path, phenopacket_path: Path) -> None:
    """
    Prepare a text file input for Phen2Gene from a phenopacket.
    Args:
        output_dir (Path): Path to the output directory to write text file.
        phenopacket_path (Path): Path to the phenopacket file.
    """
    output_dir.mkdir(exist_ok=True)
    phenopacket = phenopacket_reader(phenopacket_path)
    phenotypic_profile = PhenopacketUtil(phenopacket).observed_phenotypic_features()
    output_file_path = output_dir.joinpath(phenopacket_path.name + ".txt")
    write_hpo_ids_to_output_file(output_file_path, phenotypic_profile)


def prepare_inputs(output_dir: Path, phenopacket_dir: Path) -> None:
    """
    Prepare text files input for Phen2Gene from a directory of phenopackets.
    Args:
        output_dir (Path): Path to the output directory to write text files.
        phenopacket_dir (Path): Path to the phenopacket directory.
    """
    for phenopacket_path in all_files(phenopacket_dir):
        prepare_input(output_dir, phenopacket_path)



from pathlib import Path

import polars as pl
from pheval.post_processing.post_processing import SortOrder, generate_gene_result
from pheval.utils.file_utils import all_files
from pheval.utils.phenopacket_utils import GeneIdentifierUpdater, create_gene_identifier_map


def read_phen2gene_result(phen2gene_result: Path) -> pl.DataFrame:
    """
    Read Phen2Gene tsv output.
    Args:
        phen2gene_result (Path): Path to the Phen2Gene raw result
    Returns:
        pd.DataFrame: Dataframe containing the Phen2Gene result.
    """
    return pl.read_csv(phen2gene_result, separator="\t")


def extract_gene_results(
    phen2gene_result: pl.DataFrame, gene_identifier_updator: GeneIdentifierUpdater
) -> pl.DataFrame:
    return phen2gene_result.select(
        [
            pl.col("Gene").alias("gene_symbol"),
            pl.col("Gene")
            .map_elements(gene_identifier_updator.find_identifier, return_dtype=pl.String)
            .alias("gene_id"),
            pl.col("Score").alias("score"),
        ]
    )


def create_standardised_results(
    results_dir: Path, output_dir: Path, phenopacket_dir: Path, sort_order: str
) -> None:
    """
    Write standardised gene results from default Phen2Gene TSV output.
    Args:
        results_dir (Path): Path to the raw result directory.
        output_dir (Path): Path to the output directory.
        phenopacket_dir (Path): The path to the phenopacket directory.
        sort_order (str): The sort order.
    """
    gene_identifier_updator = GeneIdentifierUpdater(
        identifier_map=create_gene_identifier_map(), gene_identifier="ensembl_id"
    )
    sort_order = SortOrder.ASCENDING if sort_order == "ascending" else SortOrder.DESCENDING
    for result in all_files(results_dir):
        phen2gene_tsv_result = read_phen2gene_result(result)
        pheval_gene_result = extract_gene_results(phen2gene_tsv_result, gene_identifier_updator)
        generate_gene_result(
            results=pheval_gene_result,
            sort_order=sort_order,
            output_dir=output_dir,
            result_path=result,
            phenopacket_dir=phenopacket_dir,
        )



from pathlib import Path

import click
from pheval.prepare.custom_exceptions import MutuallyExclusiveOptionError

from pheval_phen2gene.prepare.prepare_commands import prepare_commands
from pheval_phen2gene.prepare.prepare_inputs import prepare_inputs


@click.command("prepare-inputs")
@click.option(
    "--phenopacket-dir",
    "-p",
    metavar="Path",
    required=True,
    help="Path to phenopacket directory.",
    type=Path,
)
@click.option(
    "--output-dir",
    "-o",
    metavar="Path",
    required=True,
    help="Path to output directory.",
    type=Path,
)
def prepare_inputs_command(phenopacket_dir: Path, output_dir: Path):
    """
    Prepare input for Phen2Gene from a phenopacket directory.
    Args:
        phenopacket_dir (Path): Path to the phenopacket directory.
        output_dir (Path): Path to the directory to write the input txt files.
    """
    prepare_inputs(output_dir=output_dir, phenopacket_dir=phenopacket_dir)


@click.command("prepare-commands")
@click.option(
    "--environment",
    "-e",
    required=False,
    default="local",
    show_default=True,
    help="Environment to run commands.",
    type=click.Choice(["local", "docker"]),
)
@click.option(
    "--file-prefix",
    "-f",
    required=True,
    metavar=str,
    type=str,
    help="Prefix for output batch file.",
)
@click.option(
    "--output-dir",
    "-o",
    required=True,
    metavar="PATH",
    type=Path,
    help="Directory for batch file to be output.",
)
@click.option(
    "--results-dir",
    "-r",
    required=True,
    metavar="PATH",
    type=Path,
    help="Relative path for results to be output by Phen2gene.",
)
@click.option(
    "--data-dir",
    "-d",
    required=True,
    metavar="PATH",
    type=Path,
    help="Path to Phen2Gene data directory.",
)
@click.option(
    "--phenopacket-dir",
    "-p",
    required=False,
    metavar="PATH",
    help="Path to phenopacket directory.",
    cls=MutuallyExclusiveOptionError,
    mutually_exclusive=["input_dir"],
)
@click.option(
    "--input-dir",
    "-i",
    required=False,
    metavar="PATH",
    help="Path to input text file directory.",
    cls=MutuallyExclusiveOptionError,
    mutually_exclusive=["phenopacket_dir"],
)
@click.option(
    "--phen2gene-py",
    "-py",
    required=False,
    metavar="Path",
    type=Path,
    help="Path to Phen2Gene python executable - not required if running with docker.",
)
def prepare_commands_command(
    environment: str,
    file_prefix: str,
    output_dir: Path,
    results_dir: Path,
    data_dir: Path,
    phenopacket_dir: Path or None = None,
    input_dir: Path or None = None,
    phen2gene_py: Path or None = None,
):
    """
    Prepare commands for Phen2Gene.
    Args:
        environment (str): Environment to run Phen2Gene.
        file_prefix (str): Prefix for command file path.
        output_dir (Path): Path to directory to write command file.
        results_dir (Path): Path to the directory to write Phen2Gene results.
        data_dir (Path): Path to the Phen2Gene data directory.
        phenopacket_dir (Path or None): Path to the Phenopacket directory.
        input_dir (Path or None): Path to the input file directory.
        phen2gene_py (Path or None): Path to the Phen2Gene python executable file.
    """
    output_dir.joinpath("tool_input_commands").mkdir(parents=True, exist_ok=True)
    prepare_commands(
        environment,
        file_prefix,
        output_dir.joinpath("tool_input_commands"),
        results_dir,
        data_dir,
        phenopacket_dir,
        input_dir,
        phen2gene_py,
    )



from pathlib import Path

from pydantic import BaseModel, Field


class PostProcessing(BaseModel):
    """
    Postprocessing configuration.
    Attributes:
        score_order (str): The order of the results, either ascending or descending.
    """

    score_order: str = Field(...)


class Phen2GeneToolSpecificConfigurations(BaseModel):
    """
    Phen2Gene tool specific configuration options.
    Attributes:
        environment (str): The environment to run Phen2Gene tool, either local or docker.
        phen2gene_python_executable (Path): The path to the Phen2Gene python executable
        post_process (PostProcessing): The post-processing configurations.
    """

    environment: str = Field(...)
    phen2gene_python_executable: Path = Field(...)
    post_process: PostProcessing = Field(...)



import os
import subprocess
from dataclasses import dataclass
from pathlib import Path

import docker
from pheval.utils.file_utils import all_files

from pheval_phen2gene.prepare.prepare_commands import prepare_commands
from pheval_phen2gene.tool_specific_configuration_parser import Phen2GeneToolSpecificConfigurations


def prepare_phen2gene_commands(
    config: Phen2GeneToolSpecificConfigurations,
    tool_input_commands_dir: Path,
    testdata_dir: Path,
    data_dir: Path,
    raw_results_dir: Path,
):
    """
    Prepare commands to run Phen2Gene.
    Args:
        config (Phen2GeneToolSpecificConfigurations): Phen2Gene tool configurations
        tool_input_commands_dir (Path): Path to the tool input commands directory.
        testdata_dir (Path): Path to the testdata directory.
        data_dir (Path): Path to the data directory.
        raw_results_dir (Path): Path to the directory to write raw results.
    """
    phenopacket_dir = Path(testdata_dir).joinpath("phenopackets")
    prepare_commands(
        environment=config.environment,
        file_prefix=os.path.basename(testdata_dir),
        output_dir=tool_input_commands_dir,
        results_dir=Path(
            os.path.relpath(Path(raw_results_dir)),
            start=os.getcwd(),
        ),
        phenopacket_dir=phenopacket_dir,
        path_to_phen2gene_dir=data_dir.joinpath(config.phen2gene_python_executable),
        data_dir=data_dir.joinpath("lib"),
    )


def run_phen2gene_local(testdata_dir: Path, tool_input_commands_dir: Path):
    """
    Run Phen2Gene locally.
    Args:
        testdata_dir (Path): Path to the testdata directory.
        tool_input_commands_dir (Path): Path to the directory containing tool input commands file.
    """
    batch_file = [
        file
        for file in all_files(tool_input_commands_dir)
        if file.name.startswith(Path(testdata_dir).name)
    ][0]
    print("running phen2gene")
    subprocess.run(
        ["bash", str(batch_file)],
        shell=False,
    )


def read_docker_batch(batch_file: Path) -> [str]:
    """
    Read docker batch file of Phen2Gene commands.
    Args:
        batch_file (Path): Path to the batch file of Phen2Gene commands.
    Returns:
        List[str]: List of docker commands for Phen2Gene.
    """
    with open(batch_file) as batch:
        commands = batch.readlines()
    batch.close()
    return commands


@dataclass
class DockerMounts:
    """
    Mount points for Docker containers.
    Args:
        results_dir (str): Path to the results directory.
        input_dir (str): Path to the input directory.
    """

    results_dir: str
    input_dir: str


def mount_docker(output_dir: Path, input_dir: Path) -> DockerMounts:
    """
    Create Docker mounts for volumes.
    Args:
        output_dir (Path): Path to the output directory.
        input_dir (Path): Path to the input directory.
    Returns:
        DockerMounts: Mount points for docker containers.
    """
    results_dir = f"{output_dir}{os.sep}:/phen2gene-results"
    input_dir = f"{input_dir}{os.sep}:/phen2gene-data"
    return DockerMounts(results_dir=results_dir, input_dir=input_dir)


def run_phen2gene_docker(
    input_dir: Path, testdata_dir: Path, tool_input_commands_dir: Path, raw_results_dir: Path
):
    """
    Run Phen2Gene with docker.
    Args:
        input_dir (Path): Path to the input directory.
        testdata_dir (Path): Path to the test data directory.
        tool_input_commands_dir (Path): Path to the tool input commands directory.
        raw_results_dir (Path): Path to the raw results directory.
    """
    client = docker.from_env()
    batch_file = [
        file
        for file in all_files(tool_input_commands_dir)
        if file.name.startswith(os.path.basename(testdata_dir))
    ][0]
    batch_commands = read_docker_batch(batch_file)
    mounts = mount_docker(
        output_dir=raw_results_dir,
        input_dir=input_dir,
    )
    vol = [mounts.results_dir, mounts.input_dir]
    for command in batch_commands:
        container = client.containers.run(
            "genomicslab/phen2gene",
            command,
            volumes=[str(x) for x in vol],
            detach=True,
        )
        for line in container.logs(stream=True):
            print(line.strip())
        break


def run_phen2gene(
    config: Phen2GeneToolSpecificConfigurations,
    input_dir: Path,
    testdata_dir: Path,
    tool_input_commands_dir: Path,
    raw_results_dir: Path,
):
    """
    Run Phen2Gene.
    Args:
        config (Phen2GeneToolSpecificConfigurations): Phen2Gene tool configurations.
        input_dir (Path): Path to the input directory.
        testdata_dir (Path): Path to the test data directory.
        tool_input_commands_dir (Path): Path to the tool input commands directory.
        raw_results_dir (Path): Path to the raw results directory.
    """
    if config.environment == "docker":
        run_phen2gene_docker(
            input_dir=input_dir,
            testdata_dir=testdata_dir,
            tool_input_commands_dir=tool_input_commands_dir,
            raw_results_dir=raw_results_dir,
        )
    if config.environment == "local":
        run_phen2gene_local(
            testdata_dir=testdata_dir, tool_input_commands_dir=tool_input_commands_dir
        )



import click

from pheval_phen2gene.cli_phen2gene import prepare_commands_command, prepare_inputs_command


@click.group()
def main():
    pass


main.add_command(prepare_inputs_command)
main.add_command(prepare_commands_command)

if __name__ == "__main__":
    main()



from pathlib import Path

from pheval_phen2gene.post_process.post_process_results_format import create_standardised_results
from pheval_phen2gene.tool_specific_configuration_parser import Phen2GeneToolSpecificConfigurations


def post_process_results_format(
    raw_results_dir: Path,
    output_dir: Path,
    phenopacket_dir: Path,
    config: Phen2GeneToolSpecificConfigurations,
):
    """
    Create pheval gene result from Phen2Gene tsv output.
    Args:
        raw_results_dir (Path): Path to the raw result directory.
        output_dir (Path): Path to the output directory.
        phenopacket_dir (Path): Path to the phenopacket directory.
        config (Phen2GeneToolSpecificConfigurations): Phen2Gene tool configurations.
    """
    print("...creating pheval gene results format...")
    create_standardised_results(
        results_dir=raw_results_dir,
        output_dir=output_dir,
        phenopacket_dir=phenopacket_dir,
        sort_order=config.post_process.score_order,
    )
    print("done")



import os
from dataclasses import dataclass
from pathlib import Path
from typing import List

from pheval.utils.file_utils import all_files
from pheval.utils.phenopacket_utils import PhenopacketUtil, phenopacket_reader


@dataclass
class Phen2GeneCommandLineArguments:
    """
    Minimal arguments required to run Phen2Gene on the command line.
    Args:
        path_to_phen2gene_dir (Path): Path to the Phen2Gene directory
        output_dir (Path): Path to the output directory.
        output_file_name (Path): Name of the output file.
        input_file_path (Path): Path to the input file.
        hpo_ids (List[str]): List of hpo ids.
    """

    path_to_phen2gene_dir: Path
    output_dir: Path
    output_file_name: Path
    input_file_path: [Path] = None
    hpo_ids: List[str] = None


@dataclass
class Phen2GeneDockerArguments:
    """
    Minimal arguments required to run Phen2Gene on docker.
    Args:
        output_dir (Path): Path to the output directory.
        output_file_name (Path): Name of the output file.
        input_file_path (Path): Path to the input file
        hpo_ids (List[str]): List of hpo ids.
    """

    output_dir: Path
    output_file_name: Path
    input_file_path: [Path] = None
    hpo_ids: List[str] = None


def create_command_line_arguments(
    path_to_phen2gene_dir: Path,
    output_dir: Path,
    output_file_name: Path,
    input_file_path: Path or None = None,
    phenopacket_path: Path or None = None,
) -> Phen2GeneCommandLineArguments:
    """
    Create command line arguments required for Phen2Gene.
    Args:
        path_to_phen2gene_dir (Path): Path to the Phen2Gene directory.
        output_dir (Path): Path to the output directory.
        output_file_name (Path): Name of the output file.
        input_file_path (Path or None): Path to the input file.
        phenopacket_path (Path or None): Path to the phenopacket.
    Returns:
        Phen2GeneCommandLineArguments: Arguments required to run Phen2Gene.
    """
    if phenopacket_path is None:
        return Phen2GeneCommandLineArguments(
            path_to_phen2gene_dir=path_to_phen2gene_dir,
            output_dir=output_dir,
            output_file_name=output_file_name,
            input_file_path=input_file_path,
        )
    if input_file_path is None:
        phenopacket = phenopacket_reader(phenopacket_path)
        return Phen2GeneCommandLineArguments(
            path_to_phen2gene_dir=path_to_phen2gene_dir,
            output_dir=output_dir,
            output_file_name=output_file_name,
            hpo_ids=[
                hpo.type.id for hpo in PhenopacketUtil(phenopacket).observed_phenotypic_features()
            ],
        )


def create_docker_arguments(
    output_dir: Path,
    output_file_name: Path,
    input_file_path: Path or None = None,
    phenopacket_path: Path or None = None,
) -> Phen2GeneDockerArguments:
    """
    Create the docker arguments required for Phen2Gene.
    Args:
        output_dir (Path): Path to the output directory.
        output_file_name (Path): Name of the output file.
        input_file_path (Path or None): Path to the input file.
        phenopacket_path (Path or None): Path to the phenopacket.
    """
    if phenopacket_path is None:
        return Phen2GeneDockerArguments(
            output_dir=output_dir,
            output_file_name=output_file_name,
            input_file_path=input_file_path,
        )
    if input_file_path is None:
        phenopacket = phenopacket_reader(phenopacket_path)
        return Phen2GeneDockerArguments(
            output_dir=output_dir,
            output_file_name=output_file_name,
            hpo_ids=[
                hpo.type.id for hpo in PhenopacketUtil(phenopacket).observed_phenotypic_features()
            ],
        )


class CommandWriter:
    """Class for writing all commands to a text file."""

    def __init__(self, output_file: Path):
        """
        Initialise the CommandWriter class.
        Args:
            output_file (Path): Path to the output file to write commands.
        """
        self.file = open(output_file, "w")

    def write_local_command(
        self, command_arguments: Phen2GeneCommandLineArguments, data_dir: Path
    ) -> None:
        """
        Write a Phen2Gene command to run locally.
        Args:
            command_arguments (Phen2GeneCommandLineArguments): Phen2Gene command line arguments.
            data_dir (Path): Path to Phen2Gene input data directory.
        """
        try:
            if command_arguments.hpo_ids is None:
                # TODO create this as a list instead in another method and then do "\n".join here
                # TODO so that I can test that it was done correctly
                self.file.write(
                    "python3 "
                    + str(command_arguments.path_to_phen2gene_dir)
                    + " --file "
                    + str(command_arguments.input_file_path)
                    + " -out "
                    + f"{str(command_arguments.output_dir)}{os.sep}"
                    + " --name "
                    + str(command_arguments.output_file_name)
                    + " -d "
                    + str(data_dir)
                    + "\n"
                )
            if command_arguments.input_file_path is None:
                self.file.write(
                    "python3 "
                    + str(command_arguments.path_to_phen2gene_dir)
                    + " --manual "
                    + " ".join(command_arguments.hpo_ids)
                    + " -out "
                    + f"{str(command_arguments.output_dir)}{os.sep}"
                    + " --name "
                    + str(command_arguments.output_file_name)
                    + " -d "
                    + str(data_dir)
                    + "\n"
                )
        except IOError:
            print("Error writing ", self.file)

    def write_docker_command(self, command_arguments: Phen2GeneDockerArguments) -> None:
        """
        Write a Phen2Gene command to run with docker.
        Args:
            command_arguments (Phen2GeneDockerArguments): Arguments passed to docker command for Phen2Gene.
        """
        try:
            if command_arguments.hpo_ids is None:
                self.file.write(
                    " --file "
                    + str(command_arguments.input_file_path)
                    + " -out "
                    + "/phen2gene-results"
                    + " --name "
                    + str(command_arguments.output_file_name)
                    + " -d "
                    + "/phen2gene-data"
                    + "\n"
                )
            if command_arguments.input_file_path is None:
                self.file.write(
                    " --manual "
                    + " ".join(command_arguments.hpo_ids)
                    + " -out "
                    + "/phen2gene-results"
                    + " --name "
                    + str(command_arguments.output_file_name)
                    + " -d "
                    + "/phen2gene-data"
                    + "\n"
                )
        except IOError:
            print("Error writing ", self.file)

    def close(self):
        """Close the file."""
        self.file.close()


def write_single_local_command(
    path_to_phen2gene_dir: Path,
    output_dir: Path,
    output_file_name: Path,
    data_dir: Path,
    command_writer: CommandWriter,
    input_file_path: Path or None = None,
    phenopacket_path: Path or None = None,
) -> None:
    """
    Write a single command locally when given either a phenopacket or prepared input file.
    Args:
        path_to_phen2gene_dir (Path): Path to the Phen2Gene directory.
        output_dir (Path): Path to the output directory.
        output_file_name (Path): Name of the output file.
        data_dir (Path): Path to the Phen2Gene data directory.
        command_writer (CommandWriter): CommandWriter instance.
        input_file_path (Path or None): Path to the input file.
        phenopacket_path (Path or None): Path to the phenopacket.
    """
    arguments = create_command_line_arguments(
        path_to_phen2gene_dir=path_to_phen2gene_dir,
        output_dir=output_dir,
        output_file_name=output_file_name,
        input_file_path=input_file_path,
        phenopacket_path=phenopacket_path,
    )
    command_writer.write_local_command(arguments, data_dir)


def write_single_docker_command(
    output_dir: Path,
    output_file_name: Path,
    command_writer: CommandWriter,
    input_file_path: Path or None = None,
    phenopacket_path: Path or None = None,
) -> None:
    """
    Write a docker command when given either a phenopacket or prepared input file.
    Args:
        output_dir (Path): Path to the output directory.
        output_file_name (Path): Name of the output file.
        command_writer (CommandWriter): CommandWriter instance.
        input_file_path (Path or None): Path to the input file.
        phenopacket_path (Path or None): Path to the phenopacket.
    """
    arguments = create_docker_arguments(
        output_dir=output_dir,
        output_file_name=output_file_name,
        input_file_path=input_file_path,
        phenopacket_path=phenopacket_path,
    )
    command_writer.write_docker_command(arguments)


def write_local_commands(
    path_to_phen2gene_dir: Path,
    command_file_path: Path,
    output_dir: Path,
    data_dir: Path,
    phenopacket_dir: Path or None,
    input_dir: Path or None,
) -> None:
    """
    Write all commands to run locally when given either directory containing phenopackets or input files.
    Args:
        path_to_phen2gene_dir (Path): Path to the Phen2Gene directory.
        command_file_path (Path): Path to the file to write commands.
        output_dir (Path): Path to the output directory.
        data_dir (Path): Path to the Phen2Gene data directory.
        phenopacket_dir (Path or None): Path to the phenopacket directory.
        input_dir (Path or None): Path to the input file directory.
    """
    input_files = all_files(phenopacket_dir) if input_dir is None else all_files(input_dir)
    command_writer = CommandWriter(command_file_path)
    for input_file in input_files:
        (
            write_single_local_command(
                path_to_phen2gene_dir=path_to_phen2gene_dir,
                output_dir=output_dir,
                output_file_name=Path(input_file.stem),
                command_writer=command_writer,
                input_file_path=input_file,
                data_dir=data_dir,
            )
            if phenopacket_dir is None
            else write_single_local_command(
                path_to_phen2gene_dir=path_to_phen2gene_dir,
                output_dir=output_dir,
                output_file_name=Path(input_file.stem),
                command_writer=command_writer,
                phenopacket_path=input_file,
                data_dir=data_dir,
            )
        )
    command_writer.close()


def write_docker_commands(
    command_file_path: Path,
    output_dir: Path,
    phenopacket_dir: Path or None,
    input_dir: Path or None,
) -> None:
    """
    Write all commands to run with docker when given either directory containing phenopackets or input files.
    Args:
        command_file_path (Path): Path to the file to write commands.
        output_dir (Path): Path to the output directory.
        phenopacket_dir (Path or None): Path to the phenopacket directory.
        input_dir (Path or None): Path to the input file directory.
    """
    input_files = all_files(phenopacket_dir) if input_dir is None else all_files(input_dir)
    command_writer = CommandWriter(command_file_path)
    for input_file in input_files:
        (
            write_single_docker_command(
                output_dir=output_dir,
                output_file_name=Path(input_file.stem),
                command_writer=command_writer,
                phenopacket_path=input_file,
            )
            if input_dir is None
            else write_single_docker_command(
                output_dir=output_dir,
                output_file_name=Path(input_file.stem),
                command_writer=command_writer,
                input_file_path=input_file,
            )
        )


def prepare_commands(
    environment: str,
    file_prefix: str,
    output_dir: Path,
    results_dir: Path,
    data_dir: Path,
    phenopacket_dir: Path or None = None,
    input_dir: Path or None = None,
    path_to_phen2gene_dir: Path or None = None,
) -> None:
    """
    Prepare all commands to run with Phen2Gene.
    Args:
        environment (str): Environment to run Phen2Gene commands.
        file_prefix (str): Prefix for command file path.
        output_dir (Path): Path to the directory to write command file.
        results_dir (Path): Path to the directory to write Phen2Gene results.
        data_dir (Path): Path to the Phen2Gene data directory.
        phenopacket_dir (Path or None): Path to the phenopacket directory.
        input_dir (Path or None): Path to the input file directory.
        path_to_phen2gene_dir (Path or None): Path to the Phen2Gene directory.
    """
    command_file_path = output_dir.joinpath(f"{file_prefix}-phen2gene-batch.txt")
    if environment == "local":
        write_local_commands(
            path_to_phen2gene_dir=path_to_phen2gene_dir,
            command_file_path=command_file_path,
            phenopacket_dir=phenopacket_dir,
            input_dir=input_dir,
            output_dir=results_dir,
            data_dir=data_dir,
        )
    if environment == "docker":
        write_docker_commands(
            command_file_path=command_file_path,
            output_dir=results_dir,
            phenopacket_dir=phenopacket_dir,
            input_dir=input_dir,
        )



"""Phen2Gene Runner"""

from dataclasses import dataclass
from pathlib import Path

from pheval.runners.runner import PhEvalRunner

from pheval_phen2gene.post_process.post_process import post_process_results_format
from pheval_phen2gene.run.run import prepare_phen2gene_commands, run_phen2gene
from pheval_phen2gene.tool_specific_configuration_parser import Phen2GeneToolSpecificConfigurations


@dataclass
class Phen2GenePhEvalRunner(PhEvalRunner):
    """_summary_"""

    input_dir: Path
    testdata_dir: Path
    tmp_dir: Path
    output_dir: Path
    config_file: Path

    def prepare(self):
        """prepare"""
        print("preparing")

    def run(self):
        """run"""
        print("running with phen2gene")
        tool_specific_configurations = Phen2GeneToolSpecificConfigurations.parse_obj(
            self.input_dir_config.tool_specific_configuration_options
        )
        prepare_phen2gene_commands(
            config=tool_specific_configurations,
            tool_input_commands_dir=self.tool_input_commands_dir,
            testdata_dir=self.testdata_dir,
            data_dir=self.input_dir,
            raw_results_dir=self.raw_results_dir,
        )
        run_phen2gene(
            config=tool_specific_configurations,
            testdata_dir=self.testdata_dir,
            input_dir=self.input_dir,
            raw_results_dir=self.raw_results_dir,
            tool_input_commands_dir=self.tool_input_commands_dir,
        )

    def post_process(self):
        """post_process"""
        print("post processing")
        tool_specific_configurations = Phen2GeneToolSpecificConfigurations.parse_obj(
            self.input_dir_config.tool_specific_configuration_options
        )
        post_process_results_format(
            raw_results_dir=self.raw_results_dir,
            output_dir=self.output_dir,
            phenopacket_dir=self.testdata_dir.joinpath("phenopackets"),
            config=tool_specific_configurations,
        )
